import React, { useEffect, useState } from "react";
import axios from "axios";
import { jwtDecode } from "jwt-decode";

function PracticeHome() {
  const [username, setUsername] = useState("");
  const [privilege, setPrivilege] = useState("");
  const [protectedData, setProtectedData] = useState(null);
  const [unprotectedData, setUnprotectedData] = useState(null);

  // Function to decode JWT token and extract user info
  const decodeToken = () => {
    // get token from localstorage
    const token = localStorage.getItem("jwtToken");

    // exit early if no token found
    if (!token) {
      console.log("No token found");
      return;
    }

    // decode the token using jwt_decode
    try {
      const decoded = jwtDecode(token);
      setUsername(decoded.username);
      setPrivilege(decoded.role);
    } catch (error) {
      console.error("Error decoding token: ", error);
    }
  };

  // function to make call to unprotected backend endpoint
  const fetchUnprotectedData = async () => {
    // since the endpoint is unprotected, do not need token
    // this would be for all guest methods (search, login, etc)

    try {
      const response = await axios.get(
        `${process.env.REACT_APP_API_URL}/user/public`
      );
      setUnprotectedData(response.data);
    } catch (error) {
      console.error("error fetching public endpoint: ", error);
    }
  };

  const fetchProtectedData = async () => {
    const token = localStorage.getItem("jwtToken");

    if (!token) {
      console.error("no token found. ");
      return;
    }

    try {
      const response = await axios.get(
        `${process.env.REACT_APP_API_URL}/protected`,
        {
          headers: {
            Authorization: `Bearer ${token}`,
          },
        }
      );
      setProtectedData(response.data);
    } catch (error) {
      console.error("Error fetching protected data: ", error);
    }
  };

  // Fetch data on component mount
  useEffect(() => {
    decodeToken();
    fetchUnprotectedData();
  }, []);

  return (
    <div>
      <h1>Welcome to the Practice Home Page</h1>

      {/* Display user information from the decoded token */}
      {username && (
        <div>
          <h2>User Info</h2>
          <p>Username: {username}</p>
          <p>Privilege: {privilege}</p>
        </div>
      )}

      <div>
        <h2>Unprotected API Data</h2>
        <button onClick={fetchUnprotectedData}>Fetch Unprotected Data</button>
        {unprotectedData && (
          <pre>{JSON.stringify(unprotectedData, null, 2)}</pre>
        )}
      </div>

      <div>
        <h2>Protected API Data</h2>
        <button onClick={fetchProtectedData}>Fetch Protected Data</button>
        {protectedData && <pre>{JSON.stringify(protectedData, null, 2)}</pre>}
      </div>
    </div>
  );
}

export default PracticeHome;
